#ifndef SETTINGSDIALOG_H
#define SETTINGSDIALOG_H

#include <QDialog>

class configReader;

namespace Ui {
    class settingsDialog;
}

class settingsDialog : public QDialog
{
    Q_OBJECT

public:
    explicit settingsDialog(QWidget *parent = 0);
    ~settingsDialog();

public slots:
    void ddmmyyyy();
    void mmddyyyy();
    void yyyyddmm();
    void yyyymmdd();

    void sepDash();
    void sepSlash();
    void sepNone();

private:
    Ui::settingsDialog *ui;
    configReader *settParent;

    void updateRadioBtns();
    void updateExamples();
};

#endif // SETTINGSDIALOG_H
